"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var forms_1 = require("@angular/forms");
var hql_1 = require("../shared/data/hql");
var message_service_1 = require("../../shared/service/message.service");
var developer_service_1 = require("../shared/service/developer.service");
var global_constants_1 = require("../../shared/global.constants");
var bitmessage_1 = require("../../shared/data/bitmessage");
/**
 * Clase que implementa la consulta de información con consultas HQL.
 */
var HQLComponent = /** @class */ (function () {
    /** Constructor de la clase. */
    function HQLComponent(developerService, formBuilder, messageService) {
        this.developerService = developerService;
        this.formBuilder = formBuilder;
        this.messageService = messageService;
        this.breadcrumb = [];
        this.messages = new Map();
    }
    /** Inicializa la ficha: define la validación. */
    HQLComponent.prototype.ngOnInit = function () {
        this.init();
        this.hqlControl = this.formBuilder.control('', [forms_1.Validators.required]);
        this.breadcrumb = [];
        this.breadcrumb.push({ label: 'Developer' });
        this.breadcrumb.push({ label: 'SQL/HQL' });
        this.messages.set(global_constants_1.PageStatus.Init, "Introdueixi el SQL/HQL");
        this.messages.set(global_constants_1.PageStatus.Searching, "Executant la sentència");
        this.messages.set(global_constants_1.PageStatus.FinishSearch, "Sentència executada correctament");
    };
    /** Inicializa el componente. */
    HQLComponent.prototype.init = function () {
        this.status = global_constants_1.PageStatus.Init;
        this.hql = hql_1.HQL.newObject();
        this.hql.reset();
    };
    /** Envía la consulta/ejecución de HQL. */
    HQLComponent.prototype.sendSHQL = function (esHQL, execute, simulate) {
        var _this = this;
        // Evitamos iniciar una nueva búsqueda cuando la anterior aún está en curso (p. ej., double click)
        if (this.status === global_constants_1.PageStatus.Searching) {
            return;
        }
        this.status = global_constants_1.PageStatus.Searching;
        //this._developerService.sendHQLTest()
        this.developerService.sendSHQL(esHQL, this.hql, execute, simulate)
            .subscribe(function (result) {
            _this.hql = result;
            _this.status = global_constants_1.PageStatus.FinishSearch;
        }, function (error) {
            _this.status = global_constants_1.PageStatus.Error;
            var titulo = (simulate) ? "Resultat de la simulació" : "Error";
            var cuerpo = error.text + (error.trazaError ? ("\nTraça:\n" + error.trazaError) : "");
            _this.messageService.sendMessage(new bitmessage_1.BitMessage(titulo, cuerpo));
        });
    };
    /** Limpia la información de consulta/ejecución. */
    HQLComponent.prototype.resetForm = function () {
        this.init();
    };
    Object.defineProperty(HQLComponent.prototype, "searchInitiated", {
        /** Flag: la página está realizando la búsqueda. */
        get: function () { return this.status === global_constants_1.PageStatus.Init; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(HQLComponent.prototype, "searching", {
        /** Flag: la página está realizando la búsqueda. */
        get: function () { return this.status === global_constants_1.PageStatus.Searching; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(HQLComponent.prototype, "searchFinished", {
        /** Flag: la página ha finalizado la última búsqueda. */
        get: function () { return this.status === global_constants_1.PageStatus.FinishSearch; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(HQLComponent.prototype, "diagnostic", {
        /** Información de debug. */
        get: function () { return JSON.stringify(this.hql); },
        enumerable: true,
        configurable: true
    });
    HQLComponent = __decorate([
        core_1.Component({
            selector: 'hql',
            template: "\n\n     <bit-header [noToolbar]=\"true\" [breadcrumb]=breadcrumb></bit-header>\n\n     <div class=\"panel panel-filtro\">\n       <div class=\"panel-heading\">\n         <i></i>&nbsp;&nbsp;&nbsp;SQL/HQL\n       </div>\n       <div class=\"panel-body\">\n           <form role=\"form\"> <!-- #f=\"ngForm\"-->\n           <div class=\"form-group\">\n             <div class=\"row\">\n                 <div class=\"col-xs-12\">\n                     <textarea class=\"form-control h-200\" id=\"hql\" name=\"hql\" [(ngModel)]=\"hql.hql\" [formControl]=\"hqlControl\"></textarea>\n                 </div>\n             </div>\n           </div>\n           </form>\n       </div>\n       <div class=\"panel-footer text-center\">\n         <div class=\"btn-group\" role=\"group\">\n           <button type=\"reset\" class=\"btn btn-default\" (click)=\"resetForm()\">Neteja&nbsp;&nbsp;<span class=\"glyphicon glyphicon-erase\"></span></button>\n         </div>\n         <div class=\"btn-group\" role=\"group\">\n           <button type=\"reset\" class=\"btn btn-default\" [disabled]=\"!hqlControl.valid\" (click)=\"sendSHQL(false, false, false)\">Query SQL&nbsp;&nbsp;<span class=\"glyphicon glyphicon-search\"></span></button>\n         </div>\n         <div class=\"btn-group\" role=\"group\">\n           <button type=\"reset\" class=\"btn btn-default\" [disabled]=\"!hqlControl.valid\" (click)=\"sendSHQL(true, false, false)\">Query HQL&nbsp;&nbsp;<span class=\"glyphicon glyphicon-search\"></span></button>\n         </div>\n         <div class=\"btn-group\" role=\"group\">\n           <button type=\"reset\" class=\"btn btn-info\" [disabled]=\"!hqlControl.valid\" (click)=\"sendSHQL(false, false, true)\">Simula SQL&nbsp;&nbsp;<span class=\"glyphicon glyphicon-send\"></span></button>\n         </div>\n         <div class=\"btn-group\" role=\"group\">\n           <button type=\"reset\" class=\"btn btn-warning\" [disabled]=\"!hqlControl.valid\" (click)=\"sendSHQL(false, true, false)\">Executa SQL&nbsp;&nbsp;<span class=\"glyphicon glyphicon-flash\"></span></button>\n         </div>\n         <div class=\"btn-group\" role=\"group\">\n           <button type=\"reset\" class=\"btn btn-warning\" [disabled]=\"!hqlControl.valid\" (click)=\"sendSHQL(true, true, false)\">Executa HQL&nbsp;&nbsp;<span class=\"glyphicon glyphicon-flash\"></span></button>\n         </div>\n       </div>\n     </div>\n\n     <div>\n           <pre class=\"mensaje\" [hidden]=\"!hql.resultado\">{{hql.resultado}}</pre> <!-- (!searchFinished || errorMessage)-->\n     </div>\n     <div style=\"height: 150px;\">\n     </div>\n\n     <bit-footer [paginator]=\"false\" type=\"form\" [status]=\"status\" [messages]=\"messages\"></bit-footer>\n\n     <!--footer class=\"footer navbar-fixed-bottom\">\n         <ul class=\"navbar-right\">\n             <li>\n                 <span class=\"mensaje mensaje-informacion\" *ngIf=\"searchInitiated\"><i class=\"glyphicon glyphicon-info-sign\"></i>Introdueixi el HQL i premi \"Query\" o \"Execute\"</span>\n                 <span class=\"mensaje mensaje-informacion\" *ngIf=\"searching\">Cercant...</span>\n                 <span class=\"mensaje mensaje-error\" *ngIf=\"searchFinished && !errorMessage\"><i class=\"glyphicon glyphicon-alert\"></i>HQL executat</span>\n                 <span class=\"mensaje mensaje-error\" *ngIf=\"errorMessage\"><i class=\"glyphicon glyphicon-alert\"></i>{{errorMessage}}</span>\n             </li>\n         </ul>\n     </footer-->\n   "
        }),
        __metadata("design:paramtypes", [developer_service_1.DeveloperService,
            forms_1.FormBuilder,
            message_service_1.MessageService])
    ], HQLComponent);
    return HQLComponent;
}());
exports.HQLComponent = HQLComponent;
//# sourceMappingURL=hql.component.js.map