"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var paginator_1 = require("primeng/components/paginator/paginator");
var rxjs_1 = require("rxjs");
var global_constants_1 = require("../global.constants");
var base_filter_1 = require("../../base/shared/base.filter");
/**
* Componenente que muestra un paginador en la sección footer.
**/
var BitFooterComponent = /** @class */ (function () {
    function BitFooterComponent() {
        this.mostrarAvisos = true;
        this.fixed = true; //indicará si lo queremos fijo abajo en la página. Por defecto sí.
        this.itemsPerPage = base_filter_1.BaseFilter.RESULTADOS_PAGE; // número de elementos por página que mostramos
        this.onPageChange = new core_1.EventEmitter(); //para notificar cambios en la página a mostrar
        this.onNewPageSize = new core_1.EventEmitter(); //para notificar cambios en los elementos a mostrar por página
        this.baseItemsPerPage = base_filter_1.BaseFilter.RESULTADOS_PAGE; // guardamos el número de resultados preconfigurados por página para mostrar la lista de x, x+10 y x+20
    }
    BitFooterComponent_1 = BitFooterComponent;
    BitFooterComponent.prototype.ngOnInit = function () {
        if (this.typeFooter == undefined) {
            this.typeFooter = "list";
        }
        if (this.paginator == undefined) {
            this.paginator = false;
        } //mensajes por defecto si no vienen definidos
        if (this.messages == undefined && this.typeFooter === BitFooterComponent_1.TYPE_LIST) {
            this.messages = new Map();
            this.messages.set(global_constants_1.PageStatus.Init, "Introdueixi els criteris de cerca i premi 'Cerca'");
            this.messages.set(global_constants_1.PageStatus.Searching, "Cercant...");
            this.messages.set(global_constants_1.PageStatus.FinishSearch, "No s'ha trobat cap dada amb les dades introduïdes");
        }
        else if (this.messages == undefined && this.typeFooter === BitFooterComponent_1.TYPE_FORM) {
            this.messages = new Map();
            this.messages.set(global_constants_1.PageStatus.Init, "Premi el botó Desa per actualitzar les dades");
            this.messages.set(global_constants_1.PageStatus.Searching, "Enviant la sol·licitud...");
            this.messages.set(global_constants_1.PageStatus.FinishSearch, "Dades actualitzades satisfactòriament");
        }
        else if (this.messages == undefined && this.typeFooter === BitFooterComponent_1.TYPE_BLANK) {
            console.log('the footer is BLANK!');
            this.messages = new Map();
        }
    };
    /**
    * Cuando tengamos la referncia al componente paginator nos suscribimos al observable para recibir la notificación
    * de que se ha realizado una autobúsqueda con una página y/o resultados por página diferente al estándar
    */
    BitFooterComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        this.autoQueryObs && this.autoQueryObs.subscribe(function (filter) {
            if (_this.pc) {
                _this.itemsPerPage = filter.resultados;
                _this.pc._rows = filter.resultados;
                _this.pc._first = (filter.pagina - 1) * _this.pc._rows;
                _this.pc.updatePageLinks();
            }
        });
    };
    /**
     * Escucharemos a cambios en las propiedades totalItems para actualizar el paginador con respecto a las páginas que mostramos
     */
    BitFooterComponent.prototype.ngOnChanges = function (changes) {
        var log = [];
        for (var propName in changes) {
            var changedProp = changes[propName];
            if (propName === 'totalItems') {
                this.totalItems = changedProp.currentValue;
                (changedProp.previousValue !== changedProp.currentValue) ? this.calculatePageLinkSize() : undefined; //recalculamos
            }
        }
    };
    /** Calcula el número de enlaces visibles en el paginador (en el rango entre 1 y 20). */
    BitFooterComponent.prototype.calculatePageLinkSize = function () {
        this.pageLinkSize = Math.ceil(this.totalItems / this.itemsPerPage);
        if (this.pageLinkSize < 1) {
            this.pageLinkSize = 1;
        }
        if (this.pageLinkSize > 20) {
            this.pageLinkSize = 20;
        }
    };
    /** Establece el número de página en la visualización de resultados. Se invoca cuando el usuario cambia el número de resultados a mostrar o cambia de página */
    BitFooterComponent.prototype.paginate = function (event) {
        console.log("Page changed to", event.page);
        if (event.rows !== this.itemsPerPage) { // han cambiado el número de elementos por página
            //notificamos que los elementos por pagina han cambiado
            this.onNewPageSize.emit(event.rows);
            this.itemsPerPage = event.rows;
            this.calculatePageLinkSize(); // recalculamos el número de enlaces de página
        }
        else {
            //notificamos a nuestro papa que la página ha cambiado 
            this.onPageChange.emit(event.page + 1);
        }
    };
    BitFooterComponent.prototype.getStyle = function () {
        if (this.fixed) {
            return "footer navbar-fixed-bottom";
        }
        else {
            return "footer";
        }
    };
    Object.defineProperty(BitFooterComponent.prototype, "searchInitiated", {
        /** Flag: la página está realizando la búsqueda. */
        get: function () { return this.status === global_constants_1.PageStatus.Init; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "searching", {
        /** Flag: la página está realizando la búsqueda. */
        get: function () { return this.status === global_constants_1.PageStatus.Searching; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "searchFinished", {
        /** Flag: la página ha finalizado la última búsqueda. */
        get: function () { return this.status === global_constants_1.PageStatus.FinishSearch; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "readOnly", {
        /** Flag: la página está en modo solo lectura */
        get: function () { return this.status == global_constants_1.PageStatus.ReadOnly; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "error", {
        /** Flag: la página ha finalizado con error */
        get: function () { return this.status == global_constants_1.PageStatus.Error; },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "foundResult", {
        /** Flag: encontrado resultado. */
        get: function () { return (this.totalItems > 0); },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "emptyResult", {
        /** Flag: no hay resultados. */
        get: function () { return (this.totalItems === 0); },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "initMessage", {
        get: function () { return this.messages.get(global_constants_1.PageStatus.Init); },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "searchingMessage", {
        get: function () { return this.messages.get(global_constants_1.PageStatus.Searching); },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "finishMessage", {
        get: function () { return this.messages.get(global_constants_1.PageStatus.FinishSearch); },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BitFooterComponent.prototype, "readOnlyMessage", {
        get: function () { return this.messages.get(global_constants_1.PageStatus.ReadOnly); },
        enumerable: true,
        configurable: true
    });
    var BitFooterComponent_1;
    BitFooterComponent.TYPE_LIST = 'list';
    BitFooterComponent.TYPE_FORM = 'form';
    BitFooterComponent.TYPE_BLANK = 'blank';
    __decorate([
        core_1.ViewChild("pc"),
        __metadata("design:type", paginator_1.Paginator)
    ], BitFooterComponent.prototype, "pc", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", rxjs_1.Observable)
    ], BitFooterComponent.prototype, "autoQueryObs", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Number)
    ], BitFooterComponent.prototype, "totalItems", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Boolean)
    ], BitFooterComponent.prototype, "paginator", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Boolean)
    ], BitFooterComponent.prototype, "mostrarAvisos", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Boolean)
    ], BitFooterComponent.prototype, "fixed", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Number)
    ], BitFooterComponent.prototype, "status", void 0);
    __decorate([
        core_1.Input("type"),
        __metadata("design:type", String)
    ], BitFooterComponent.prototype, "typeFooter", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Map)
    ], BitFooterComponent.prototype, "messages", void 0);
    __decorate([
        core_1.Output(),
        __metadata("design:type", Object)
    ], BitFooterComponent.prototype, "onPageChange", void 0);
    __decorate([
        core_1.Output(),
        __metadata("design:type", Object)
    ], BitFooterComponent.prototype, "onNewPageSize", void 0);
    BitFooterComponent = BitFooterComponent_1 = __decorate([
        core_1.Component({
            selector: 'bit-footer',
            template: "\n<footer [class]=\"getStyle()\">\n    <div>\n        <ul *ngIf=\"typeFooter === 'list'\" [hidden]=\"emptyResult\" class=\"paginas\">\n            <li><label>&nbsp;&nbsp;&nbsp;&nbsp;Nombre de resultats:</label></li>\n            <li class=\"valor\"><span>{{totalItems}}</span></li>\n            <li *ngIf=\"paginator\">\n                <!-- Hay un bug con pageLinkSize. Pese a recalcularlo bien cuando se selecciona otra ventana de resultados. El componenten no lo actualiza hasta cambiar de p\u00E1gina--> \n                <p-paginator #pc [rows]=\"itemsPerPage\" [totalRecords]=\"totalItems\" [pageLinkSize]=\"pageLinkSize\" [rowsPerPageOptions]=\"[baseItemsPerPage,baseItemsPerPage*2,baseItemsPerPage*5,baseItemsPerPage*10,baseItemsPerPage*20]\" (onPageChange)=\"paginate($event)\"></p-paginator>\n            </li>\n        </ul>\n        <ul class=\"navbar-right\">\n            <li>                    \n                <span class=\"mensaje mensaje-informacion\" *ngIf=\"searchInitiated\"><i class=\"glyphicon glyphicon-info-sign\"></i>{{initMessage}}</span>\n                <span class=\"mensaje mensaje-informacion\" *ngIf=\"searching\">{{searchingMessage}}</span>\n                <span class=\"mensaje mensaje-informacion\" *ngIf=\"readOnly\">{{readOnlyMessage}}</span>\n                <span class=\"mensaje mensaje-error\" *ngIf=\"!searching && (searchFinished && emptyResult)\"><i class=\"glyphicon glyphicon-alert\"></i>{{finishMessage}}</span>\n                <span class=\"mensaje mensaje-error\" *ngIf=\"error\"><i class=\"glyphicon glyphicon-alert\"></i>S'ha produ\u00EFt un error</span>\n                <bit-help></bit-help>\n            </li>\n        </ul>\n    </div>\n</footer>\n"
        })
    ], BitFooterComponent);
    return BitFooterComponent;
}());
exports.BitFooterComponent = BitFooterComponent;
//# sourceMappingURL=bit-footer.component.js.map