"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var toolbar_service_1 = require("../service/toolbar.service");
/**
* Componenente que muestra una barra de botones.
* @Input() componentId contiene el identificador del componente que contiene este toolbar. Es opcional en cuyo caso el valor será "BASE"
* @Output() onToolbarButtonPressed. El componente captura la pulsación de estos botones y envia un evento onToolbarButtonPressed con el nombre del
* botón pulsado.
**/
var BitToolbarComponent = /** @class */ (function () {
    function BitToolbarComponent(toolbarService) {
        this.toolbarOld = {}; // ya no se usa
        this.femenino = false; // género femenino (para los nombres de botones) o no
        this.componentId = "BASE"; // id del componente donde está asociado el toolbar por defecto BASE
        this.otherActionsDropdown = false; // determina si las "other actions" deben mostrarse en línea o como un desplegable
        this.onToolbarButtonPressed = new core_1.EventEmitter();
        this.toolbar = {};
        this.toolbarService = toolbarService;
    }
    BitToolbarComponent_1 = BitToolbarComponent;
    BitToolbarComponent.prototype.ngAfterContentInit = function () {
        console.log("soy el ToolbarComponent " + this.componentId);
        this.registerObservable();
    };
    BitToolbarComponent.prototype.registerObservable = function () {
        var _this = this;
        this.toolbarSubscription = this.toolbarService.observableToolbar.subscribe(function (newToolbar) {
            if (!newToolbar) {
                return; // un evento sin toolbar, no hay nada que hacer
            }
            if (!_this.componentId) { // si no tenemos componentId somos el único toolbar en pantalla, lo aceptamos sí o sí
                _this.setToolbar(newToolbar);
            }
            else {
                // tenemos componentId, por lo que probablemente hay varios toolbar simultáneos en pantalla
                // comprobamos si el evento indica que ha cambiado el que nos interesa y, en caso contrario, lo ignoramos
                if (_this.componentId === newToolbar.componentId) {
                    _this.setToolbar(newToolbar);
                }
            }
        });
    };
    BitToolbarComponent.prototype.enable = function (button) {
        return this.toolbar[button] && this.toolbar[button].enable;
    };
    BitToolbarComponent.prototype.visible = function (button) {
        return this.toolbar[button] && this.toolbar[button].visible;
    };
    BitToolbarComponent.prototype.label = function (button, defaultLabel) {
        return (this.toolbar[button] && this.toolbar[button].label) || defaultLabel;
    };
    BitToolbarComponent.prototype.estilo = function (button, defaultValue) {
        return (this.toolbar[button] && this.toolbar[button].estilo) || defaultValue || "fa fa-balance-spinner";
    };
    BitToolbarComponent.prototype.showFilter = function () {
        this.onToolbarButtonPressed.emit(BitToolbarComponent_1.FILTER_BUTTON);
    };
    BitToolbarComponent.prototype.print = function () {
        this.onToolbarButtonPressed.emit(BitToolbarComponent_1.PRINT_BUTTON);
    };
    BitToolbarComponent.prototype.exportData = function () {
        this.onToolbarButtonPressed.emit(BitToolbarComponent_1.EXPORT_BUTTON);
    };
    BitToolbarComponent.prototype.newElement = function () {
        this.onToolbarButtonPressed.emit(BitToolbarComponent_1.NEW_BUTTON);
    };
    BitToolbarComponent.prototype.add = function () {
        this.onToolbarButtonPressed.emit(BitToolbarComponent_1.ADD_BUTTON);
    };
    BitToolbarComponent.prototype.save = function () {
        this.onToolbarButtonPressed.emit(BitToolbarComponent_1.SAVE_BUTTON);
    };
    BitToolbarComponent.prototype.delete = function () {
        this.onToolbarButtonPressed.emit(BitToolbarComponent_1.DELETE_BUTTON);
    };
    BitToolbarComponent.prototype.otherAction = function (button) {
        this.onToolbarButtonPressed.emit(button.action);
    };
    BitToolbarComponent.prototype.ngOnDestroy = function () {
        this.toolbarSubscription.unsubscribe();
    };
    BitToolbarComponent.prototype.setToolbar = function (newToolbar) {
        this.toolbar = newToolbar;
        // calcular si las other actions deben mostrarse en desplegable
        // (se ha pedido asi y hay más de una)
        var otherActionsVisibles = 0;
        for (var key in this.toolbar) {
            if (this.toolbar[key].otherAction && this.toolbar[key].visible) {
                otherActionsVisibles++;
            }
        }
        this.mostrarOtherActionsEnDesplegable = this.otherActionsDropdown && otherActionsVisibles > 1;
    };
    var BitToolbarComponent_1;
    BitToolbarComponent.FILTER_BUTTON = "filter";
    BitToolbarComponent.PRINT_BUTTON = "print";
    BitToolbarComponent.EXPORT_BUTTON = "export";
    BitToolbarComponent.NEW_BUTTON = "new";
    BitToolbarComponent.SAVE_BUTTON = "save";
    BitToolbarComponent.DELETE_BUTTON = "delete";
    BitToolbarComponent.ADD_BUTTON = "add";
    BitToolbarComponent.HELP_BUTTON = "help";
    __decorate([
        core_1.Input("toolbar"),
        __metadata("design:type", Object)
    ], BitToolbarComponent.prototype, "toolbarOld", void 0);
    __decorate([
        core_1.Input("ayuda"),
        __metadata("design:type", String)
    ], BitToolbarComponent.prototype, "ayuda", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Boolean)
    ], BitToolbarComponent.prototype, "femenino", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", String)
    ], BitToolbarComponent.prototype, "componentId", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Boolean)
    ], BitToolbarComponent.prototype, "otherActionsDropdown", void 0);
    __decorate([
        core_1.Output(),
        __metadata("design:type", Object)
    ], BitToolbarComponent.prototype, "onToolbarButtonPressed", void 0);
    BitToolbarComponent = BitToolbarComponent_1 = __decorate([
        core_1.Component({
            selector: 'bit-toolbar',
            template: "\n<!-- acciones no estandar definidas din\u00E1micamente o muy particulares-->\n<!-- si otherActionsDropdown viene a true y hay m\u00E1s de una acci\u00F3n, se muestran como un desplegable, si no, todas las acciones en l\u00EDnea -->\n<div class=\"btn-group dropdown\" role=\"group\" *ngIf=\"mostrarOtherActionsEnDesplegable\">\n    <button type=\"button\" *ngIf=\"otherActionsDropdown\"\n        class=\"btn btn-dinamico btn-accion dropdown-toggle\" data-toggle=\"dropdown\"\n        aria-haspopup=\"true\" aria-expanded=\"false\">Accions&nbsp;&nbsp;<span class=\"fa fa-caret-right\"></span></button>\n    <div class=\"dropdown-menu desplegable-accion\">\n        <ng-container *ngFor=\"let button of (toolbar | otherToolbarAction)\">\n            <button type=\"button\" \n                *ngIf=\"button.visible\"\n                [disabled]=\"!button.enable\" (click)=\"otherAction(button)\" class=\"btn btn-dinamico btn-accion dropdown-item\"\n            ><span [class]=\"button.estilo?button.estilo:'fa fa-caret-right'\"></span>&nbsp;&nbsp;{{button.label}}</button>\n        </ng-container>\n    </div>\n</div>\n\n<!-- si otherActionsDropdown viene a false o solo hay una acci\u00F3n, se muestran una tras otra en l\u00EDnea -->\n<div class=\"btn-inline\" *ngIf=\"!mostrarOtherActionsEnDesplegable\">\n    <ng-container *ngFor=\"let button of (toolbar | otherToolbarAction)\">\n        <div *ngIf=\"button.visible\" class=\"btn-group\" role=\"group\">\n            <button type=\"button\" [disabled]=\"!button.enable\" (click)=\"otherAction(button)\" class=\"btn btn-dinamico btn-accion\">{{button.label}}&nbsp;&nbsp;<span [class]=\"button.estilo?button.estilo:'fa fa-caret-right'\"></span></button>\n        </div>\n    </ng-container>\n</div>\n\n<!-- acciones estandar -->\n<div class=\"btn-group\" role=\"group\" *ngIf=\"visible('new')\">\n    <button type=\"button\" [disabled]=\"!enable('new')\" (click)=\"newElement()\" class=\"btn btn-danger\">{{label('new', (femenino?'Nova':'Nou'))}}&nbsp;&nbsp;<span [class]=\"estilo('new', 'fa fa-plus')\"></span></button>\n</div>\n<div class=\"btn-group\" role=\"group\" *ngIf=\"visible('add')\">\n    <button type=\"button\" [disabled]=\"!enable('add')\" (click)=\"add()\" class=\"btn btn-danger\">{{label('nova', 'Afegeix')}}&nbsp;&nbsp;<span [class]=\"estilo('add', 'fa fa-plus')\"></span></button>\n</div>\n<!--div class=\"btn-group\" role=\"group\" *ngIf=\"visible('filter')\">\n    <button type=\"button\" [disabled]=\"!enable('filter')\" (click)=\"showFilter()\" class=\"btn btn-transparent\">{{label('filter', 'Mostra filtre')}}&nbsp;&nbsp;<span [class]=\"estilo('filter', 'glyphicon glyphicon-search')\"></span></button>\n</div-->\n<div class=\"btn-group\" role=\"group\" *ngIf=\"visible('export')\">\n    <button type=\"button\" [disabled]=\"!enable('export')\" (click)=\"exportData()\" class=\"btn btn-transparent\">{{label('export', 'Exporta')}}&nbsp;&nbsp;<span [class]=\"estilo('export', 'glyphicon glyphicon-file')\"></span></button>\n</div>\n<div class=\"btn-group\" role=\"group\" *ngIf=\"visible('save')\">\n    <button type=\"button\" [disabled]=\"!enable('save')\" (click)=\"save()\" class=\"btn btn-success\">{{label('save', 'Desa')}}&nbsp;&nbsp;<span [class]=\"estilo('save', 'glyphicon glyphicon-floppy-disk')\"></span></button>\n</div>\n<div class=\"btn-group\" role=\"group\" *ngIf=\"visible('delete')\">\n    <button type=\"button\" [disabled]=\"!enable('delete')\" (click)=\"delete()\" class=\"btn btn-transparent btn-transparent-danger\">{{label('delete', 'Elimina')}}&nbsp;&nbsp;<span [class]=\"estilo('delete', 'glyphicon glyphicon-remove')\"></span></button>\n</div>\n<div class=\"btn-group\" role=\"group\" *ngIf=\"visible('print')\">\n    <button type=\"button\" [disabled]=\"!enable('print')\" (click)=\"print()\" class=\"btn btn-transparent\">{{label('print', 'Imprimeix')}}&nbsp;&nbsp;<span [class]=\"estilo('print', 'glyphicon glyphicon-print')\"></span></button>\n</div>\n<div class=\"btn-group\" role=\"group\" *ngIf=\"ayuda\">\n\t<bit-boton-ayuda boton=\"true\" [ayuda]=\"ayuda\"></bit-boton-ayuda>\n</div>\n"
        }),
        __metadata("design:paramtypes", [toolbar_service_1.ToolbarService])
    ], BitToolbarComponent);
    return BitToolbarComponent;
}());
exports.BitToolbarComponent = BitToolbarComponent;
//# sourceMappingURL=bit-toolbar.component.js.map