import { ChangeDetectorRef } from "@angular/core";
import { ControlValueAccessor } from "@angular/forms";
import { AyudaService } from "../../service/ayuda.service";
import { BitGeneralComponent } from "./bit-general.component";
/** Clase customizada para componentes personalizados que requieren implementar la interface ControlValueAccessor.
 * Tipicamente para aquellos componentes personalizados que trabajan sobre otros componentes no estándars HTML como
 * pueden ser los componentes de prime como switch, autocomplete, calendar, select, etc.
 */
export declare abstract class BitCustomComponent extends BitGeneralComponent implements ControlValueAccessor {
    protected ayudaService: AyudaService;
    protected changeDetectorRef: ChangeDetectorRef;
    protected onTouchedCallback: () => void;
    protected onChangeCallback: (_: any) => void;
    constructor(ayudaService: AyudaService, changeDetectorRef: ChangeDetectorRef);
    value: any;
    /** Solo se activa este método si el input readOnly es true */
    readonly value_lectura: string;
    /** El comportamiento normal es no transformar nada. Si el componente hijo necesita transformarlo
     * que sobreecriba el método y modifique el comportamiento. Esto se dará típicamente en los campos fecha porque
     * no queremos la versión ISO que nos da Prime si no una versión españolizada*/
    transformData(v: any): any;
    /** Controlamos si debemos modificar el valor interno del componente mediante una transformacion al tener un pipe asociado*/
    onBlur(): void;
    /** Controlamos si debemos modificar el valor interno del componente mediante una transformacion al tener un pipe asociado*/
    onFocus(): void;
    /** Se activa cuando debemos Angular nos informa de que debemos actualizar la vista. Cada componente hijo deberá ver
     * si requiere o no implementar este método */
    writeValue(value: any): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
}
