"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var forms_1 = require("@angular/forms");
var router_1 = require("@angular/router");
var ayuda_service_1 = require("../../service/ayuda.service");
var session_shared_service_1 = require("../../service/session-shared.service");
var bitdropdown_general_component_1 = require("./bitdropdown-general.component");
exports.CUSTOM_DROPDOWN_CONTROL_VALUE_ACCESSOR = {
    provide: forms_1.NG_VALUE_ACCESSOR,
    useExisting: core_1.forwardRef(function () { return BitDropDownComponent; }),
    multi: true
};
/**
 * Clase que utiliza un custom componente para select de elementos
 * Utiliza la interfaz ControlValueAccessor
 *    <bit-select [domain]="'DOMAIN_TIPO_LOG'" id="tipolog" [control]="formControl">&nbsp;&nbsp;Tipus d'operació</bit-select>
 *
 * @input data: array de objetos a mostrar en el select. Puede ser null, en cuyo caso domain no puede ser null
 * @input domain: nombre del dominio que contiene los datos y que nos resolverá la página cuando cargue el componente. Puede ser null, en cuyo caso data no puede ser null
 * @input id: identificador del componente select
 * @input filter: true indicará que podemos buscar dentro del select, false que no.
 **/
var BitDropDownComponent = /** @class */ (function (_super) {
    __extends(BitDropDownComponent, _super);
    function BitDropDownComponent(router, sessionShared, ayudaService, changeDetectorRef) {
        var _this = _super.call(this, router, sessionShared, ayudaService, changeDetectorRef) || this;
        _this.router = router;
        _this.sessionShared = sessionShared;
        _this.ayudaService = ayudaService;
        _this.changeDetectorRef = changeDetectorRef;
        _this.filter = false;
        _this.emptyText = "Qualsevol"; //valor por defecto seleccionable como primer elemento
        _this.includeEmpty = true;
        _this.listaOpcionesVisible = [];
        return _this;
    }
    BitDropDownComponent.prototype.ngOnChanges = function (changes) {
        var hayCambios = false;
        for (var propName in changes) {
            var changedProp = changes[propName];
            if (propName === "data") {
                this.listaOpciones = changedProp.currentValue ? changedProp.currentValue.slice() : [];
                hayCambios = true;
            }
            else if (propName === "dominio") {
                this.domain = changedProp.currentValue;
                // TODO: recargar dominio por si es distinto?
            }
            else if (propName === "excludedValues") {
                this.excludedValues = changedProp.currentValue;
                hayCambios = true;
            }
            else if (propName === "includeEmpty") {
                this.includeEmpty = changedProp.currentValue;
                hayCambios = true;
            }
        }
        if (hayCambios) {
            this.postRetrieveData();
        }
    };
    // custom processing after retrieving data array from service
    BitDropDownComponent.prototype.postRetrieveData = function () {
        var _this = this;
        if (this.listaOpciones) {
            this.listaOpcionesVisible = Object.assign([], this.listaOpciones);
            if (this.includeEmpty) {
                // determinamos si debemos incluir la opción "sin selección" y con qué texto
                this.listaOpcionesVisible.splice(0, 0, { value: null, label: this.emptyText });
            }
            // repasamos si hay opciones a excluir que debamos eliminar
            if (this.excludedValues) {
                this.listaOpcionesVisible = this.listaOpcionesVisible.filter(function (op) { return _this.excludedValues.indexOf(op.value) < 0; });
            }
        }
    };
    Object.defineProperty(BitDropDownComponent.prototype, "value_lectura", {
        get: function () {
            var val = this.value;
            var dom = this.listaOpciones && this.listaOpciones.find(function (d) { return d.value == val; });
            return dom ? dom.label : null;
        },
        enumerable: true,
        configurable: true
    });
    __decorate([
        core_1.Input(),
        __metadata("design:type", Boolean)
    ], BitDropDownComponent.prototype, "filter", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Array)
    ], BitDropDownComponent.prototype, "excludedValues", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Boolean)
    ], BitDropDownComponent.prototype, "autoWidth", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", String)
    ], BitDropDownComponent.prototype, "emptyText", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Boolean)
    ], BitDropDownComponent.prototype, "includeEmpty", void 0);
    BitDropDownComponent = __decorate([
        core_1.Component({
            selector: "bit-dropdown",
            template: "\n    <label *ngIf=\"!hideLabel\">\n        <ng-content></ng-content>&nbsp;\n        <span *ngIf=\"obligatorio\" class=\"obligatorio fa fa-asterisk\"></span>&nbsp;&nbsp;\n        <i *ngIf=\"ayuda\" (click)=\"showAyuda()\" class=\"btn-ayuda fa fa-question\"></i>\n    </label>\n    <p *ngIf=\"readOnly\" class=\"lectura\" [id]=\"nombre\">{{value_lectura}}</p>\n    <div *ngIf=\"!readOnly\">\n        <p-dropdown \n            id=\"{{nombre}}\" \n            [(ngModel)]=\"value\"\n            [options]=\"listaOpcionesVisible\"          \n            [filter]=\"filter\"         \n            [autoWidth]=\"autoWidth\" \n            (onFocus)=\"onFocus()\" \n            (onBlur)=\"onBlur()\">\n            <ng-template let-item pTemplate=\"item\">\n                <span [ngClass]=\"{'opcion-desactivada': item.inactivo}\">{{item.label}}</span>\n            </ng-template>\n        </p-dropdown>\n        <control-messages *ngIf=\"control!=null\" [control]=\"control\" [field]=\"id\"></control-messages>\n    </div>\n  ",
            providers: [exports.CUSTOM_DROPDOWN_CONTROL_VALUE_ACCESSOR]
        }),
        __metadata("design:paramtypes", [router_1.ActivatedRoute,
            session_shared_service_1.SessionSharedService,
            ayuda_service_1.AyudaService,
            core_1.ChangeDetectorRef])
    ], BitDropDownComponent);
    return BitDropDownComponent;
}(bitdropdown_general_component_1.BitDropDownGeneralComponent));
exports.BitDropDownComponent = BitDropDownComponent;
//# sourceMappingURL=bit-dropdown.component.js.map